using System;
using System.ComponentModel;
using System.Windows.Forms;

namespace MultiColumnTree {
	/// <summary>
	/// Label with checkbox image
	/// </summary>
	public class Check : Label {
		/// <summary>
		/// The Image List contains the box with and without hook
		/// </summary>
		private System.Windows.Forms.ImageList imageList;
		private System.ComponentModel.IContainer components = null;

		public Check(System.ComponentModel.IContainer container) {
			container.Add(this);
			InitializeComponent();
		}

		public Check() {
			InitializeComponent();
			this.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.ImageIndex = 0;
			this.ImageList = this.imageList;
			this.Size = new System.Drawing.Size(15, 16);
		}

		/// <summary> 
		/// Verwendete Ressourcen bereinigen.
		/// </summary>
		protected override void Dispose( bool disposing ) {
			if( disposing ) {
				if(components != null) {
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		private void InitializeComponent() {
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(Check));
			this.imageList = new System.Windows.Forms.ImageList(this.components);
			// 
			// imageList
			// 
			this.imageList.ColorDepth = System.Windows.Forms.ColorDepth.Depth4Bit;
			this.imageList.ImageSize = new System.Drawing.Size(15, 16);
			this.imageList.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("imageList.ImageStream")));
			this.imageList.TransparentColor = System.Drawing.Color.Transparent;

		}
	
		/// <summary>
		/// Set or get the state of property check
		/// </summary>
		private bool @checked = false;
		[Browsable(true)]
		public bool Checked {
			set {
				if (@checked == value) return;
				if (value) {
					@checked = true;
					ImageIndex = 1;
				} else {
					@checked = false;
					ImageIndex = 0;
				}
			}
			get {return @checked;}
		}
		/// <summary>
		/// Toggle state with click event
		/// </summary>
		/// <param name="e"></param>
		protected override void OnClick(System.EventArgs e) {
			base.OnClick (e);
			bool old = Checked;
			bool cancel = false;
			if (CheckedChanged != null) {
				MultiColumnTree.EventArgs args = new MultiColumnTree.EventArgs(!Checked);
				CheckedChanged(this, args);
				cancel = args.Cancel;
			}
			if (cancel == false) {
				Checked = ! old;
			} else {
				Checked = old;
			}
		}

		/// <summary>
		/// Event changed state
		/// </summary>
		public event MultiColumnTree.Tree.CheckChangedHandler CheckedChanged;

	}

}
