using System;
using System.ComponentModel;
using System.Collections;
using System.Diagnostics;
using System.Windows.Forms;
using System.Drawing;

namespace MultiColumnTree
{
	/// <summary>
	/// Zusammenfassung fr TreeSymbol.
	/// </summary>
	public class TreeSymbol : PictureBox
	{

		static TreeSymbols symbols = new TreeSymbols();
		static int counter = 1;
		private Tree.FilterType filter;

		private System.ComponentModel.IContainer components;

		#region Constructors
		public TreeSymbol(System.ComponentModel.IContainer container)
		{
			///
			/// Erforderlich fr Windows.Forms Klassenkompositions-Designeruntersttzung
			///
			container.Add(this);
			InitializeComponent();
		}

		public TreeSymbol() : base()
		{
			///
			/// Erforderlich fr Windows.Forms Klassenkompositions-Designeruntersttzung
			///
			InitializeComponent();
			this.Name = counter.ToString("dddddddd");
			this.Anchor = System.Windows.Forms.AnchorStyles.Left;
			this.TabStop = false;
		}

		public TreeSymbol(MCTNode treeNode,int height, Tree.FilterType filter) : base() {

			InitializeComponent();
			this.Name = counter.ToString("dddddddd");
			this.Anchor = System.Windows.Forms.AnchorStyles.Left;
			this.TabStop = false;
			this.filter = filter;

			Image treePicture = GetImage(treeNode);
			this.Image = treePicture;
			this.Tag = treeNode;
			this.Size = treePicture.Size;
			this.Height = height;
		}

		public TreeSymbol(MCTNode treeNode,int height, bool line) : base() {

			InitializeComponent();
			this.Name = counter.ToString("dddddddd");
			this.Anchor = System.Windows.Forms.AnchorStyles.Left;
			this.TabStop = false;

			if (line) {
				this.Image = symbols.PbxLineI.Image;
			} else {
				this.Image = symbols.PbxNoLine.Image;
			}
			this.Tag = treeNode;
			this.Size = this.Image.Size;
			this.Height = height;
		}
		#endregion
		
		/// <summary> 
		/// Verwendete Ressourcen bereinigen.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}


		#region Vom Komponenten-Designer generierter Code
		/// <summary>
		/// Erforderliche Methode fr die Designeruntersttzung. 
		/// Der Inhalt der Methode darf nicht mit dem Code-Editor gendert werden.
		/// </summary>
		private void InitializeComponent()
		{

		}
		#endregion

		/// <summary>
		/// Determine the tree images in a row
		/// </summary>
		/// <param name="treeNode">actual node</param>
		/// <returns></returns>
		private Image GetImage (MCTNode treeNode) {
			PictureBox treeSymbol;
			if (treeNode.Nodes.Count == 0) {
				if (treeNode.Parent.Text == "...") {
					treeSymbol = symbols.PbxLineI;
				} else {
					if (treeNode.Parent.LastNode(filter) == treeNode) {
						treeSymbol = symbols.PbxLineL;
					} else {
						treeSymbol = symbols.PbxLineT;
					}
				}
			} else {
				if (treeNode.IsExpanded) {
					if (treeNode.Parent.Nodes.Count == 1) {
						treeSymbol = symbols.PbxMinusI;
					} else {
						if (treeNode.Parent.Text == "...") {
							if (treeNode.Index == 0) {
								treeSymbol = symbols.PbxMinusR;
							} else {
								treeSymbol = symbols.PbxMinusL;
							}
						} else {
							if (treeNode.Parent.LastNode(filter) == treeNode) {
								treeSymbol = symbols.PbxMinusL;
							} else {
								treeSymbol = symbols.PbxMinusT;
							}
						}
					}
				} else {
					if (treeNode.Parent.Nodes.Count == 1) {
						treeSymbol = symbols.PbxPlusI;
					} else {
						if (treeNode.Parent.Text == "...") {
							if (treeNode.Index == 0) {
								treeSymbol = symbols.PbxPlusR;
							} else {
								treeSymbol = symbols.PbxPlusL;
							}
						} else {
							if (treeNode.Parent.LastNode(filter) == treeNode) {
								treeSymbol = symbols.PbxPlusL;
							} else {
								treeSymbol = symbols.PbxPlusT;
							}
						}
					}
				}
			}
			return treeSymbol.Image;
		}


		/// <summary>
		/// On Click event
		/// </summary>
		/// <param name="e"></param>
		protected override void OnClick(System.EventArgs e) {
			MCTNode treeNode = this.Tag as MCTNode;
			treeNode.Toggle();
			this.Image = GetImage(treeNode);
			base.OnClick (e);
		}

	}
}
